Package: BiocPkgDash
Type: Package
Title: An interactive Shiny dashboard for Bioconductor package
        maintainers
Version: 1.1.0
Authors@R: c(
  person(
    "Marcel", "Ramos", , "marcel.ramos@sph.cuny.edu", c("aut", "cre"),
    c(ORCID = "0000-0002-3242-0582")
  ),
  person("Vincent", "Carey", , "stvjc@channing.harvard.edu", "aut")
  )
Description: This package provides an interactive Shiny dashboard for
  Bioconductor package maintainers. It visualizes various package statuses,
  metadata, and development metrics, offering insights into package health and
  activity. This tool aims to support maintainers of multiple packages by
  filtering packages via maintainer email.
Depends: R (>= 4.6.0), shiny
Imports: BiocBaseUtils, BiocPkgTools (>= 1.27.6), BiocManager, bsicons,
        bslib, dplyr, DT, ggplot2, gh, htmlwidgets, plotly, rmarkdown,
        shinybiocloader, shinyjs, tibble, tidyr, utils, whisker, yaml
Suggests: BiocStyle, knitr, sessioninfo, tinytest
biocViews: Software, Infrastructure, Visualization, GUI
VignetteBuilder: knitr
License: Artistic-2.0
Encoding: UTF-8
URL: https://github.com/Bioconductor/BiocPkgDash
BugReports: https://github.com/Bioconductor/BiocPkgDash/issues
RoxygenNote: 7.3.3
Roxygen: list(markdown = TRUE)
Date: 2026-03-23
git_url: https://git.bioconductor.org/packages/BiocPkgDash
git_branch: devel
git_last_commit: 489cd3b
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:30:42 UTC; biocbuild
Author: Marcel Ramos [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3242-0582>),
  Vincent Carey [aut]
Maintainer: Marcel Ramos <marcel.ramos@sph.cuny.edu>
