---
output: github_document
knit: (function(inputFile, encoding) {
  rmarkdown::render(inputFile, encoding = encoding, output_dir = "../../") })
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
    root.dir = ".",
    collapse = TRUE,
    comment = "#>",
    fig.path = "man/figures/README-",
    cache = TRUE,
    out.width = "100%"
)
```

```{r,echo=FALSE,eval=FALSE}
## Generate the ./README.md (relative to base folder)
rmarkdown::render(input = "inst/scripts/README.Rmd", output_dir = ".")
```

```{r, child="../../vignettes/BiocPkgDash.Rmd"}

```
