## ----install, eval=FALSE------------------------------------------------------
# if (!requireNamespace("BiocManager", quietly = TRUE))
#     install.packages("BiocManager")
# 
# BiocManager::install("BiocPkgDash")

## ----load,include=TRUE,results="hide",message=FALSE,warning=FALSE-------------
library(BiocPkgDash)

## ----display,eval=FALSE-------------------------------------------------------
# BiocPkgDash()

## ----mainapp,echo=FALSE-------------------------------------------------------
img_path <-
    if (knitr::opts_knit$get("child")) "man/figures/" else "../man/figures/"
knitr::include_graphics(paste0(img_path, "BiocPkgDash.png"))

## ----sidebarpanel,echo=FALSE--------------------------------------------------
img_path <-
    if (knitr::opts_knit$get("child")) "man/figures/" else "../man/figures/"
knitr::include_graphics(paste0(img_path, "BiocPkgDash_filter.png"))

## ----badgewall,echo=FALSE-----------------------------------------------------
img_path <-
    if (knitr::opts_knit$get("child")) "man/figures/" else "../man/figures/"
knitr::include_graphics(paste0(img_path, "BiocPkgDash_badges.png"))

## ----pkgStatus,echo=FALSE-----------------------------------------------------
img_path <-
    if (knitr::opts_knit$get("child")) "man/figures/" else "../man/figures/"
knitr::include_graphics(paste0(img_path, "BiocPkgDash_status.png"))

## ----session------------------------------------------------------------------
sessionInfo()

