% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pkgStatusPlot.R
\name{pkgStatusPlot}
\alias{pkgStatusPlot}
\title{A Summary Plot for Package Statuses}
\usage{
pkgStatusPlot(
  data = NULL,
  status = c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped"),
  stage = c("install", "buildsrc", "checksrc", "buildbin")
)
}
\arguments{
\item{data}{\code{tibble()} / \code{data.frame()} A data frame of maintained packages.
This is used internally to avoid repeated calls to the
\code{\link[BiocPkgTools:biocMaintained]{BiocPkgTools::biocMaintained()}} function.}

\item{status}{\code{character()} A vector of \code{INSTALL}, \code{build} and \code{check}
statuses to include in the plot. These values are obtained from the
\code{result} column in \code{\link[BiocPkgTools:biocBuildReport]{BiocPkgTools::biocBuildReport()}}. The default is all:
\code{c("OK", "WARNINGS", "ERROR", "TIMEOUT", "skipped")}.}

\item{stage}{\code{character()} A vector of the Bioconductor Build System (BBS)
stages to include in the plot. These values are obtained from the \code{stage}
\code{\link[BiocPkgTools:biocBuildReport]{BiocPkgTools::biocBuildReport()}}. The default is all stages:
\code{c("install", "buildsrc", "checksrc", "buildbin")}.}
}
\value{
An interactive \code{ggplotly} object.
}
\description{
This function generates a stacked bar plot of package statuses for
a given Bioconductor version and email combination. It is mainly used
for the Bioconductor Package Dashboard.
}
\details{
Note that binary build stages for the Linux builders are not
included in the plot. This is because the binaries are built on GitHub
Actions and their result are not included in the Bioconductor Build System
(BBS) database.
}
\examples{
\dontshow{if (interactive()) withAutoprint(\{ # examplesIf}
data <- BiocPkgTools::biocMaintained(
    "maintainer@bioconductor.org", pkgType = "software"
)
pkgStatusPlot(data)
\dontshow{\}) # examplesIf}
}
