% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BiocPkgDash.R
\name{BiocPkgDash}
\alias{BiocPkgDash}
\title{The Bioconductor Package Dashboard}
\usage{
BiocPkgDash(email = NULL, ...)
}
\arguments{
\item{email}{\code{character(1)} vector providing the email of the maintainer. By
default, the package will look for the email in the URL query.}

\item{...}{Additional parameters to pass to the \code{\link[shiny:shinyApp]{shiny::shinyApp()}} function.}
}
\value{
called for the side effect of initializing a shiny app
}
\description{
A dashboard for Bioconductor package maintainers to monitor the
status of their packages. The key input to the dashboard is the email the
maintainer uses in their package's \code{DESCRIPTION} file. The dashboard
displays the badge statuses of the package in both the \code{release} or \code{devel}
branches of Bioconductor. The status is determined by the results of the
Bioconductor nightly builds. The dashboard also provides a visualization of
the status of the package checks on either the \code{release} or \code{devel}
branches of Bioconductor.
}
\examples{
\dontshow{if (interactive()) withAutoprint(\{ # examplesIf}
BiocPkgDash()
\dontshow{\}) # examplesIf}
}
